==> layer_sdk-0.9.345796-py3-none-any.whl: layer/clients/account.py <==
import uuid
from contextlib import contextmanager
from logging import Logger
from typing import Iterator

from layer.api.ids_pb2 import AccountId
from layer.api.service.user.account_api_pb2 import (
    GetAccountViewByIdRequest,
    GetAccountViewByIdResponse,
)
from layer.api.service.user.account_api_pb2_grpc import AccountAPIStub
from layer.api.service.user.user_api_pb2 import GetMyOrganizationRequest
from layer.api.service.user.user_api_pb2_grpc import UserAPIStub
from layer.config import ClientConfig
from layer.grpc_utils import create_grpc_channel
from layer.user.account import Account


class AccountClient:
    _service: UserAPIStub
    _account_api: AccountAPIStub

    def __init__(
        self,
        config: ClientConfig,
        logger: Logger,
    ):
        self._config = config.user_service
        self._logger = logger
        self._access_token = config.access_token
        self._do_verify_ssl = config.grpc_do_verify_ssl
        self._logs_file_path = config.logs_file_path

    @contextmanager
    def init(self) -> Iterator["AccountClient"]:
        with create_grpc_channel(
            self._config.address,
            self._access_token,
            do_verify_ssl=self._do_verify_ssl,
            logs_file_path=self._logs_file_path,
        ) as channel:
            self._service = UserAPIStub(channel=channel)
            self._account_api = AccountAPIStub(channel=channel)
            yield self

    def get_account_name_by_id(self, organization_id: uuid.UUID) -> str:
        get_my_org_resp: GetAccountViewByIdResponse = (
            self._account_api.GetAccountViewById(
                GetAccountViewByIdRequest(id=AccountId(value=str(organization_id))),
            )
        )
        return get_my_org_resp.account_view.name

    def get_my_account(self) -> Account:
        # TODO LAY-2692
        org = self._service.GetMyOrganization(
            GetMyOrganizationRequest(),
        ).organization
        return Account(
            id=uuid.UUID(org.id.value),
            name=org.name,
        )

==> layer_sdk-0.9.347249-py3-none-any.whl: layer/clients/account.py <==
import uuid
from contextlib import contextmanager
from logging import Logger
from typing import Iterator

from layer.api.ids_pb2 import AccountId
from layer.api.service.user.account_api_pb2 import (
    GetAccountViewByIdRequest,
    GetAccountViewByIdResponse,
)
from layer.api.service.user.account_api_pb2_grpc import AccountAPIStub
from layer.api.service.user.user_api_pb2 import GetMyOrganizationRequest
from layer.api.service.user.user_api_pb2_grpc import UserAPIStub
from layer.config import ClientConfig
from layer.grpc_utils import create_grpc_channel
from layer.user.account import Account


class AccountClient:
    _service: UserAPIStub
    _account_api: AccountAPIStub

    def __init__(
        self,
        config: ClientConfig,
        logger: Logger,
    ):
        self._config = config.user_service
        self._logger = logger
        self._access_token = config.access_token
        self._do_verify_ssl = config.grpc_do_verify_ssl
        self._logs_file_path = config.logs_file_path

    @contextmanager
    def init(self) -> Iterator["AccountClient"]:
        with create_grpc_channel(
            self._config.address,
            self._access_token,
            do_verify_ssl=self._do_verify_ssl,
            logs_file_path=self._logs_file_path,
        ) as channel:
            self._service = UserAPIStub(channel=channel)
            self._account_api = AccountAPIStub(channel=channel)
            yield self

    def get_account_name_by_id(self, account_id: uuid.UUID) -> str:
        get_my_org_resp: GetAccountViewByIdResponse = (
            self._account_api.GetAccountViewById(
                GetAccountViewByIdRequest(id=AccountId(value=str(account_id))),
            )
        )
        return get_my_org_resp.account_view.name

    def get_my_account(self) -> Account:
        # TODO LAY-2692
        org = self._service.GetMyOrganization(
            GetMyOrganizationRequest(),
        ).organization
        return Account(
            id=uuid.UUID(org.id.value),
            name=org.name,
        )
